@@ -155,3 +155,11 @@ class FTPS(SalureConnect):
             if self.debug:
                 print(ftp.nlst())
             return ftp.nlst()
+
+    def remove_file(self, remote_filepath):
+        """
+        Remove a file on a remote location
+        :param remote_file: the full path of the file that needs to be removed
+        """
+        with FTP(host=self.host, user=self.username, passwd=self.password) as ftp:
+            ftp.delete(remote_filepath)
